import { ExampleService } from '@business/services/util/example.service';
import { PageBean } from '@business/entity/grid';
import { _HttpClient } from '@delon/theme';
import { environment } from 'environments/environment';
import { RouteConfigLoadStart } from '@angular/router';
import { Injectable } from '@angular/core';
import { equal } from 'assert';
import { Observable } from 'rxjs/Observable';


@Injectable()
export class VersionService {
  private urls = {
      list: environment.SERVER_BASH_URL + '/device-version/page-list',
      save: environment.SERVER_BASH_URL + '/device-version/add-or-modify',
      delete: environment.SERVER_BASH_URL + '/device-version/delete-by-ids',
      getSensorIds: environment.SERVER_BASH_URL + '/device-version/get-sensor-ids',
      versionSensorConfig: environment.SERVER_BASH_URL + '/device-version/version-sensor-config'
  };
  constructor(private http: _HttpClient) { }
   public getPagingList(page: PageBean, queryText: string): Observable<PageBean> {
    const example = new ExampleService();
    if (queryText != null && queryText !== '') {
      example.or().andLike({name: 'name', value: '%' + queryText + '%'});
      example.or().andEqualTo({name: 'version', value: queryText});
    }
    let orderByClause = '';
    if ( page.getOrderByClause != null && page.getOrderByClause instanceof Function) {
      orderByClause = page.getOrderByClause();
    }
    const param: PageBean = {pageSize: page.pageSize, pageIndex: page.pageIndex, 
      queryParams: example.getSqlParam(), orderByClause: orderByClause};
    return this.http.get(this.urls.list, param);
  }
  public save(data: any): Observable<any> {
        return this.http.post(this.urls.save, data);
  }
  public delete(...ids: number[]): Observable<any> {             
        return this.http.post(this.urls.delete, ids);
  }
  public getSensorIds(deviceVersionId: number): Observable< number []> {
      return this.http.get(this.urls.getSensorIds, {deviceVersionId: deviceVersionId});
  }
  public versionSensorConfig(deviceVersionId: number, sensorIds: number[]): Observable<any> {
    const url = this.urls.versionSensorConfig + '/' + deviceVersionId;
    return this.http.post(url, sensorIds);
  }
}
